@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 
 use Mojo::Debugbar;
 
-our $VERSION = '0.0.2';
+our $VERSION = '0.1.1';
 
 =head2 register
 
@@ -26,20 +26,21 @@ sub register {
         $debugbar->stop;
     });
 
-    $app->hook(after_dispatch => sub {
-        my $c = shift;
-        
-        if (!$c->stash('mojo.static') && !$c->res->is_redirect && $c->res->body =~ m/<\/body>/) {
+    $app->hook(after_render => sub {
+        my ($c, $output, $format) = @_;
+
+        return unless $format eq 'html';
+
+        # if there is a </body> tag, inject the debugbar
+        if ($$output =~ m/<\/body>/) {
             # Render the debugbar html
             my $html = $debugbar->render;
 
-            my $body = $c->res->body;
-
-            # Inject the debugbar html
-            $body =~ s/<\/body>/$html\n<\/body>/ig;
-
-            # Set the new body html
-            $c->res->body($body);
+            # Append text before the closing </body> tag
+            $$output =~ s!(</body>)!$html$1!;
+        } else {
+            # Append text at the end of the output
+            $$output .= $debugbar->inject;
         }
     });
 }
